@@ -4,7 +4,7 @@
 package Scrappy::Logger;
 
 BEGIN {
-    $Scrappy::Logger::VERSION = '0.93111200';
+    $Scrappy::Logger::VERSION = '0.93111250';
 }
 
 # load OO System
@@ -17,8 +17,9 @@ use DateTime::Format::SQLite;
 use YAML::Syck;
 $YAML::Syck::ImplicitTyping = 1;
 
-has file => (is => 'rw', isa => 'Str');
-has verbose => (is => 'rw', isa => 'Int', default => 0);
+has 'auto_save' => (is => 'rw', isa => 'Bool', default => 1);
+has file        => (is => 'rw', isa => 'Str');
+has verbose     => (is => 'rw', isa => 'Int',  default => 0);
 
 
 sub load {
@@ -151,7 +152,7 @@ Scrappy::Logger - Scrappy Scraper Event Logging
 
 =head1 VERSION
 
-version 0.93111200
+version 0.93111250
 
 =head1 SYNOPSIS
 
@@ -177,6 +178,20 @@ encountered using the L<Scrappy> framework.
 The following is a list of object attributes available with every Scrappy::Logger
 instance.
 
+=head3 auto_save
+
+The auto_save attribute is a boolean that determines whether event data is
+automatically saved to the log file on update.
+
+    my  $logger = Scrappy::Logger->new;
+        
+        $logger->load('scraper.log');
+        
+        # turn auto-saving off
+        $logger->auto_save(0);
+        $logger->event('...', 'yada yada yada');
+        $logger->write; # explicit write
+
 =head3 file
 
 The file attribute gets/sets the filename of the current event-log file.
